Administration
==============

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   admin_ui.rst
   crawl/new_url.rst
   crawl/queue.rst
   crawl/crawlers.rst
   crawl/analytics.rst
   crawl/policies.rst
   crawl/recursion_depth.rst
   crawl/feeds.rst
   documents.rst
   tags.rst
   domain_settings.rst
   cookies.rst
   webhooks.rst
   excluded_urls.rst
   search_engines.rst
   permissions.rst
